---
layout: post
title: Adventures in setting up a T60 with a modern OS — RAM, TrackPoint and Vifm and Escape
---

![The laptop](/assets/t60-outside.jpg){:class="img-responsive"}

In this post we'll be discussing the new RAM that has arrived, the new file manager I've started using and a few other things.

## RAM
![The RAM](/assets/ram.jpg){:class="img-responsive"}

The new RAM finally arrived yesterday and I was quick to try and install it; however, to my dismay, it seemed to not like — at least at first. Initially, I had removed both of the old RAM sticks and replaced them with the new ones; this, however, resulted in my ThinkPad throwing an error at me, namely beeping. The ThinkPad has a bunch of beep codes that play whenever something is wrong, and I got `short short short short` which basically means that something is wrong with the RAM. I thus decided to take one of the RAM sticks out of the machine and put back one of the old ones and — voilà, it works. For some reason, it can only take 3 GB of RAM; and whilst I knew that only 3 GB could actually be addressed by the processor's chipset, I was unaware of the fact that it cannot even handle 4 GB of RAM installed. Everything I've read about this laptop indicated that 4 GB could be installed but, of those, only 3 GB could be used. The German ThinkWiki puts it as follows: —

> Maximal sind 4 GB (2x2 GB) möglich, wobei jedoch nur 3 GB vom Chipsatz angesprochen werden können. Bei eingebauten 4 GB laufen die genutzten 2x1,5 GB im Dualchannel-Modus.

This tells me that you can install a maximum of 4 GB of RAM (two 2 GB RAM sticks) whereof only 3 GB can be addressed; this seems to not be true, unfortunately.
This leaves me with the slight annoyance of having two differently sized RAM sticks installed in my machine; luckily, however, this is the maximum amount of RAM supported anyway, so it's not like I'm missing out on anything.

### Browsing with more RAM
Now that I have more RAM, browsing the web has become much more bearable and having several tabs open at once is no longer a problem; and, due to the very lightweight nature of the OS + WM combination I am using (Manjaro with i3-gaps), the operating system only needs about 250 MB of RAM, so roughly 1.75 GB are free for other programs.

## TrackPad speed
I am someone who likes their TrackPad, TouchPad and mouse to be quite sensitive; I'm unsure how anyone can endure having to have a 1 km² table to move from one end of the desktop to the other — obviously I am exaggerating, but I cannot for the life of me stand low sensitivity mouse input. Thus, it was imperative for me to increase the speed of my TouchPad but unfortunately I was not sure how this can be done on i3wm; so I did a bit of searching and found the following command, wherein the 0 can be replaced by a number:

```
xinput set-prop "TPPS/2 IBM TrackPoint" "libinput Accel Speed" +0
```

I found that, for me personally, a speed of `+0.3` works great, so adding the following line to my i3 config will automatically set the TouchPad speed upon starting i3-gaps: –

```
#Changing TrackPoint sensitivity
exec --no-startup-id xinput set-prop "TPPS/2 IBM TrackPoint" "libinput Accel Speed" +0
```

The name of your TouchPad or TrackPoint (which, in my case, is `TPPS/2 IBM TrackPoint`) can be found by running the `xinput` command on its own and looking at the output: —

```
⎡ Virtual core pointer                          id=2    [master pointer  (3)]
⎜   ↳ Virtual core XTEST pointer                id=4    [slave  pointer  (2)]
⎜   ↳ TPPS/2 IBM TrackPoint                     id=10   [slave  pointer  (2)]
⎣ Virtual core keyboard                         id=3    [master keyboard (2)]
    ↳ Virtual core XTEST keyboard               id=5    [slave  keyboard (3)]
    ↳ Power Button                              id=6    [slave  keyboard (3)]
    ↳ Video Bus                                 id=7    [slave  keyboard (3)]
    ↳ Sleep Button                              id=8    [slave  keyboard (3)]
    ↳ AT Translated Set 2 keyboard              id=9    [slave  keyboard (3)]
    ↳ ThinkPad Extra Buttons                    id=11   [slave  keyboard (3)]
```

## Remapping the Escape key
This is something I've been meaning to do for quite a while now — remapping the Escape key. I've not yet done so as the Escape key on most keyboards was in a decent position; on the T60 keyboard, however, it's very high up, above the `F1` key. This results in my frequently pressing `F1` instead of Escape, and you really have to do some finger gymnastics to actually reach that Escape key. Thus, I decided to remap the Escape key to Caps Lock on my T60 and I've achieved that by adding the following to my i3 config: —

```
#Remapping Caps Lock to Escape
exec "setxkbmap -option caps:escape"
```

This has made editing in Vim — and just general computer stuff — much easier.

## Vifm
I have also abandoned ranger as my file manager and moved over to vifm. The main reasons for that are that vifm seems to be more lightweight, it's written in C (so it's faster than ranger, which was written in Python) and it uses the Vim keybindings all over. Additionally, you can add image, pdf (and other files) previews using [Überzug](https://github.com/seebye/ueberzug), which provides image previews that are _soo_ much better than those of w3mimgdisplay; those tend to be very iffy and don't often work correctly. This is especially true when using the terminal emulator I use, namely [suckless' st (simple terminal)](https://st.suckless.org/), because the image previews barely work at all in that terminal, especially when using transparency.
Vifm on its own doesn't have any icons, which I like, but it's a feature that can very easily be patched in by adding a few lines to the vifm config file (`~/.config/vifm/vifmrc`).

The speed increase is especially noticeable on an old machine like the T60: ranger takes 1-5 seconds to open and vifm opens up almost instantaneously. It may not be as noticeable on more powerful machines, but I believe that, even there, the difference would be big enough to be noticeable. I have yet to install vifm on my main computer and my other laptop, but I will and see if the speed increase is noticeable there as well.
