---
layout: post
title: Adventures in setting up a T60 with a modern OS — SSD, more TrackPoint stuff and WiFi
---

In this post we'll be discussing the new SSD that I have installed into the computer and some more improvements that I have done to that TrackPoint.

## SSD
The SSD I ordered has finally arrived and I obviously had to start testing it out immediately; I removed the old HDD from the laptop, replaced it with the SSD, ran the installation process again and immediately noticed improvements. 
First of all, the installation process finished in a much shorter time than it did before and even though this may have partly been because of a faster internet connection at work, I found the installation of the programs themselves — in addition to the downloads — finished much more quickly.
Additionally, starting up the operating system after the installation had finished took such a short amount of time, I was honestly very surprised. I was used to having to wait for 30 to 40 seconds until the login screen appeared, but with the SSD installed it happened much more quickly; and to find out _how_ much quicker it booted, I ran `systemd-analyze` which provides information regarding the startup time: —

```
Startup finished in 2.162s (kernel) + 7.801s (userspace) = 9.963s
graphical.target reached after 6.720s in userspace
```

As you can see, the bootup time this time around was below 10 seconds! I honestly did not believe the improvement could be this dramatic, especially since I had never used an SSD before — and these aren't even the only improvements.
In addition to the much speedier startup, programs also start (and install) much more quickly. Chromium usually took around 5 to 15 seconds to start up with the old HDD, but it starts up within 3 seconds now. In addition, when installing a new package using `yay` or `pacman`, it took quite a while for the initial `:: Checking for conflicts...`, `:: Checking for inner conflicts...`,`resolving dependencies...` and `looking for conflicting packages...` commands to complete; this now takes less than a second, whereas before I frequently had to wait 30+ seconds for this to finish.

This whole ordeal has made me want to buy some SSDs for my remaining PCs to improve their speed even further; but I'm thus far not entirely sure whether the money will be worth it, as I believe they are running quickly enough already. The main reason I bought an SSD for this laptop is that it desperately needed a new drive — as was evident by the S.M.A.R.T sensor output I showed in an earlier post — and because I — seemingly correctly — believed that it would greatly improve the speed of this laptop and I thought it would be the best upgrade short of actually replacing the CPU.

## TrackPoint seizures
I love the TrackPoint — but it doesn't seem to love me. Recently I found out that the mouse cursor would frequently continue moving, even though I had already let go of it; it doesn't move quickly, but it moves enough to be noticeable and a tad annoying.
Interestingly enough, whilst browsing the Subreddit /r/ThinkPad, I stumpled upon a post detailing this exact issue — and it contained a possible fix in the comments.
Apparently, a while back a fix has been added to the Linux Kernel by Reddit user /u/lihaarp which basically allows one to set the so-called "drift time" to a different value which apparently fixes this strange problem; apparently it is now possible to change the drift time inside `/sys/devices/platform/i8042/serio1/serio2/drift_time`. The `serio2` directory unfortunately does not exist on my system, but the `drift_time` file can still be found inside the `serio1` directory.
He mentioned that creating a `udev` rule allows you to have this done on start-up, but I, unfortunately, do not know anything about `udev`; thus, for now, I have decided to add the following to my i3 config: —

```
#No more drifting
echo 25 > /sys/devices/platform/i8042/serio1/drift_time
```

Running this command does appear to mitigate the problem of the random cursor drifing and I'm quite happy about the fact that I was able to find a very simple fix for this, admittedly, only slightly annoying problem.

## WiFi
This laptop is obviously quite old — when it was released, I was still in primary school (≈ 2007) — so it isn't surprising that the WiFi card wouldn't support a lot of modern standards. But firstly, let us find the WiFi card by running `lspci | grep -i wireless` which yields the following: —

```
03:00.0 Network controller: Intel Corporation PRO/Wireless 3945ABG [Golan] Network Connection (rev 02)
```

 I was actually surprised by the fact that it supports 5 GHz networks, albeit at a rather slow speed. I am currently sitting directly in front of an AVM Fritz!Box 7490 — AVM is a German producer of very high-end networking equipment — and the bitrate of my connection is at a relatively low 54 Mbit/s.
I therefore decided to look up the data sheet of that card and found out that, indeed, the highest bitrate supported by it is 54 Mbit/s. This is because this actually just supports the following WiFi standards: `802.11a/b/g` whereas fastest standard at the moment is `802.11n`. It seems that a `802.11n` capable WiFi card actually _was_ shipped with the T60 at some point, but it's obvious that it's included in the one I have.
Luckily, however, it does have Gigabit Ethernet, so should I ever have a very fast internet connection — like I do at work — I can simply connect it to a router via LAN and download stuff that way; and, to be honest, 54 Mbit/s is plenty and I don't usually need more than that anyway.
Confirming that I do indeed have the `802.11a/b/g` adapter can also be achieved by using `iwconfig`: —

```
IEEE 802.11  ESSID:"FRITZ!Box 7490"
          Mode:Managed  Frequency:5.26 GHz  Access Point: CC:CE:1E:6A:81:49
          Bit Rate=54 Mb/s   Tx-Power=15 dBm
```

As this output clearly shows, I get a bitrate of 54 Mbit/s even though I am literally just 10 cm away from the router. My phone shows a bitrate of 400 Mbit/s.
